# $Id: Document.pm 35814 2011-10-20 12:09:53Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Giveup/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Giveup::Document;

use Aselect::UI::Login::Document -self;

sub build {
	$self->setDocumentElement($self->construct('giveup'));
}

sub response {
	my $res = super;

	my $req = $self->req;

	if($req->effective_warn eq 'false') {
		$res->status(302);
		$res->setheader(Location => $req->bare_url);
	}

	return $res;
}
